Справочник категорий льготности
Идентификатор	Описание
1	
2	УВОВ
3	Воин-интернационалист
4	Инвалид-детства
5	Инвалид по заболеванию
6	Лица, подвергшиеся радиации
7	Лица, приравненные к УВОВ
8	Призывник
9	Инвалид труда
10	Переселенцы
11	Лица приравн. к УВОВ семей погибших военнослужащих
12	Лица приравн. к УВОВ реабил. жертвы массов. полит-их репрессий
13	Лица подверг. радиац. Семипалатинцы
14	Лица подверг.радиац. Чернобольцы
15	Без категории
99	Прочее
